## What does this PR do?

Brief description of the change.

## Why?

What problem does this solve or what feature does this add?

## Changes

-
-
-

## Testing

- [ ] Ran `pytest tests/ -v` and all tests pass
- [ ] Tested manually with `kite-mcp` server
- [ ] Updated README if adding a new tool
- [ ] Updated CHANGELOG.md
